@@ -133,12 +133,14 @@
 #'
 #'   # or with different type of contrasts
 #'   # for sum contrasts, the value of the reference term is computed
-#'   mod2 <- lm(
-#'     tip ~ day + time + sex,
-#'     data = tips,
-#'     contrasts = list(time = contr.sum, day = contr.treatment(4, base = 3))
-#'   )
-#'   p_(ggcoef_model(mod2))
+#'   if (require(emmeans)) {
+#'     mod2 <- lm(
+#'       tip ~ day + time + sex,
+#'       data = tips,
+#'       contrasts = list(time = contr.sum, day = contr.treatment(4, base = 3))
+#'     )
+#'     p_(ggcoef_model(mod2))
+#'   }
 #' }
 ggcoef_model <- function (
   model,
@@ -215,7 +217,7 @@ ggcoef_model <- function (
   if (!"y" %in% names(args) && !"facet_row" %in% names(args))
     args$y <- "label_light"
 
-  if (!"colour" %in% names(args)) {
+  if (!"colour" %in% names(args) & !all(is.na(data$var_label))) {
     args$colour <- "var_label"
     if (!"colour_guide" %in% names(args)) {
       args$colour_guide <- FALSE
@@ -337,7 +339,7 @@ ggcoef_compare <- function (
     if (!"facet_col" %in% names(args)) {
       args$facet_col <- "model"
     }
-    if (!"colour" %in% names(args)) {
+    if (!"colour" %in% names(args) & !all(is.na(data$var_label))) {
       args$colour <- "var_label"
       if (!"colour_guide" %in% names(args)) {
         args$colour_guide <- FALSE
@@ -361,7 +363,7 @@ ggcoef_compare <- function (
 #'   p_(ggcoef_multinom(mod, type = "faceted"))
 #'   p_(ggcoef_multinom(
 #'     mod, type = "faceted",
-#'     y.level = c(
+#'     y.level_label = c(
 #'       "pretty happy" = "pretty happy\n(ref: very happy)",
 #'       "very happy" = "very happy"
 #'     )
@@ -441,7 +443,7 @@ ggcoef_multinom <- function (
     if (!"facet_col" %in% names(args)) {
       args$facet_col <- "y.level"
     }
-    if (!"colour" %in% names(args)) {
+    if (!"colour" %in% names(args) & !all(is.na(data$var_label))) {
       args$colour <- "var_label"
       if (!"colour_guide" %in% names(args)) {
         args$colour_guide <- FALSE
@@ -495,6 +497,11 @@ ggcoef_data <- function (
     keep_model = FALSE
   )
 
+  if (!"p.value" %in% names(data)) {
+    data$p.value <- NA_real_
+    significance <- NULL
+  }
+
   if(!is.null(significance)) {
     if (is.null(significance_labels))
       significance_labels <- paste(c("p \u2264", "p >"), significance)
@@ -706,16 +713,22 @@ ggcoef_plot <- function (
     )
 
   if(!is.null(colour) && colour %in% names(data)) {
-    if (colour_guide)
+    if (colour_guide) {
       colour_guide <- guide_legend()
+    } else {
+      colour_guide <- "none"
+    }
     p <- p +
       scale_colour_discrete(guide = colour_guide, labels = colour_labels) +
       labs(colour = colour_lab)
   }
 
   if(!is.null(shape) && shape %in% names(data)) {
-    if (shape_guide)
+    if (shape_guide) {
       shape_guide <- guide_legend()
+    } else {
+      shape_guide <- "none"
+    }
     p <- p +
       scale_shape_manual(
         values = shape_values,
