@@ -19,6 +19,7 @@
 
 # discrete
 #   ratio
+#   count
 #   facetbar
 #   blank
 
@@ -203,19 +204,19 @@ stop_if_high_cardinality <- function(data, columns, threshold) {
 
 
 
-#' ggduo - A ggplot2 generalized pairs plot for two columns sets of a data.frame
+#' \pkg{ggplot2} generalized pairs plot for two columns sets of data
 #'
 #' Make a matrix of plots with a given data set with two different column sets
 #'
 #' @details
 #' \code{types} is a list that may contain the variables
-#' 'continuous', 'combo', 'discrete', and 'na'. Each element of the list may be a function or a string.  If a string is supplied, it must implement one of the following options:
+#' 'continuous', 'combo', 'discrete', and 'na'. Each element of the list may be a function or a string.  If a string is supplied, If a string is supplied, it must be a character string representing the tail end of a \code{ggally_NAME} function. The list of current valid \code{ggally_NAME} functions is visible in a dedicated vignette.
 #'\describe{
-#'  \item{continuous}{exactly one of ('points', 'smooth', 'smooth_loess', 'density', 'cor', 'blank'). This option is used for continuous X and Y data.}
-#'  \item{comboHorizontal}{exactly one of ('box', 'box_no_facet', 'dot', 'dot_no_facet', 'facethist', 'facetdensity', 'denstrip', 'blank'). This option is used for either continuous X and categorical Y data or categorical X and continuous Y data.}
-#'  \item{comboVertical}{exactly one of ('box', 'box_no_facet', 'dot', 'dot_no_facet', 'facethist', 'facetdensity', 'denstrip', 'blank'). This option is used for either continuous X and categorical Y data or categorical X and continuous Y data.}
-#'  \item{discrete}{exactly one of ('facetbar', 'ratio', 'blank'). This option is used for categorical X and Y data.}
-#'  \item{na}{exactly one of ('na', 'blank').  This option is used when all X data is \code{NA}, all Y data is \code{NA}, or either all X or Y data is \code{NA}.}
+#'  \item{continuous}{This option is used for continuous X and Y data.}
+#'  \item{comboHorizontal}{This option is used for either continuous X and categorical Y data or categorical X and continuous Y data.}
+#'  \item{comboVertical}{This option is used for either continuous X and categorical Y data or categorical X and continuous Y data.}
+#'  \item{discrete}{This option is used for categorical X and Y data.}
+#'  \item{na}{This option is used when all X data is \code{NA}, all Y data is \code{NA}, or either all X or Y data is \code{NA}.}
 #'}
 #'
 #' If 'blank' is ever chosen as an option, then ggduo will produce an empty plot.
@@ -237,6 +238,7 @@ stop_if_high_cardinality <- function(data, columns, threshold) {
 #' @param cardinality_threshold maximum number of levels allowed in a character / factor column.  Set this value to NULL to not check factor columns. Defaults to 15
 #' @template ggmatrix-progress
 #' @param legends deprecated
+#' @param xProportions,yProportions Value to change how much area is given for each plot. Either \code{NULL} (default), numeric value matching respective length, \code{grid::\link[grid]{unit}} object with matching respective length or \code{"auto"} for automatic relative proportions based on the number of levels for categorical variables.
 #' @export
 #' @examples
 #'  # small function to display plots only if it's interactive
@@ -291,11 +293,32 @@ stop_if_high_cardinality <- function(data, columns, threshold) {
 #'      continuous = wrap("smooth_loess", alpha = 0.50, shape = "+")
 #'    ),
 #'    showStrips = FALSE
-#'  );
+#'  )
 #'
 #'  p_(pm)
 #'
+#' # Use "auto" to adapt width of the sub-plots
+#'  pm <- ggduo(
+#'    dt,
+#'    c("year", "g", "ab", "lg"),
+#'    c("batting_avg", "slug", "on_base"),
+#'    mapping = ggplot2::aes(color = lg),
+#'    xProportions = "auto"
+#'  )
 #'
+#'  p_(pm)
+#'
+#'  # Custom widths & heights of the sub-plots
+#'  pm <- ggduo(
+#'    dt,
+#'    c("year", "g", "ab", "lg"),
+#'    c("batting_avg", "slug", "on_base"),
+#'    mapping = ggplot2::aes(color = lg),
+#'    xProportions = c(6, 4, 3, 2),
+#'    yProportions = c(1, 2, 1)
+#'  )
+#'
+#'  p_(pm)
 #'
 #' # Example derived from:
 #' ## R Data Analysis Examples | Canonical Correlation Analysis.  UCLA: Institute for Digital
@@ -320,8 +343,8 @@ stop_if_high_cardinality <- function(data, columns, threshold) {
 #'
 #' ## Between correlation
 #' loess_with_cor <- function(data, mapping, ..., method = "pearson") {
-#'   x <- eval(mapping$x, data)
-#'   y <- eval(mapping$y, data)
+#'   x <- eval_data_col(data, mapping$x)
+#'   y <- eval_data_col(data, mapping$y)
 #'   cor <- cor(x, y, method = method)
 #'   ggally_smooth_loess(data, mapping, ...) +
 #'     ggplot2::geom_label(
@@ -429,7 +452,7 @@ ggduo <- function(
     continuous = "smooth_loess",
     comboVertical = "box_no_facet",
     comboHorizontal = "facethist",
-    discrete = "ratio"
+    discrete = "count"
   ),
   axisLabels = c("show", "none"),
   columnLabelsX = colnames(data[columnsX]),
@@ -442,6 +465,8 @@ ggduo <- function(
   legend = NULL,
   cardinality_threshold = 15,
   progress = NULL,
+  xProportions = NULL,
+  yProportions = NULL,
   legends = stop("deprecated")
 ) {
 
@@ -469,9 +494,12 @@ ggduo <- function(
   stop_if_high_cardinality(data, columnsX, cardinality_threshold)
   stop_if_high_cardinality(data, columnsY, cardinality_threshold)
 
+  xProportions <- ggmatrix_proportions(xProportions, data, columnsX)
+  yProportions <- ggmatrix_proportions(yProportions, data, columnsY)
+
   types <- check_and_set_ggpairs_defaults(
     "types", types,
-    continuous = "smooth_loess", discrete = "ratio", na = "na",
+    continuous = "smooth_loess", discrete = "count", na = "na",
     isDuo = TRUE
   )
 
@@ -549,7 +577,9 @@ ggduo <- function(
     data = data_,
     gg = NULL,
     progress = progress,
-    legend = legend
+    legend = legend,
+    xProportions = xProportions,
+    yProportions = yProportions
   )
 
   plotMatrix
@@ -573,18 +603,18 @@ ggduo <- function(
 # small_label_diamond <- make_small_strip(small_label_diamond, 2, 2)
 # #small_label_diamond # now with much smaller strip text
 
-#' ggpairs - A ggplot2 generalized pairs plot
+#' ggplot2 generalized pairs plot
 #'
 #' Make a matrix of plots with a given data set
 #'
 #' @details
 #' \code{upper} and \code{lower} are lists that may contain the variables
-#' 'continuous', 'combo', 'discrete', and 'na'. Each element of the list may be a function or a string.  If a string is supplied, it must implement one of the following options:
+#' 'continuous', 'combo', 'discrete', and 'na'. Each element of the list may be a function or a string.  If a string is supplied, it must be a character string representing the tail end of a \code{ggally_NAME} function. The list of current valid \code{ggally_NAME} functions is visible in a dedicated vignette.
 #'\describe{
-#'  \item{continuous}{exactly one of ('points', 'smooth', 'smooth_loess', 'density', 'cor', 'blank'). This option is used for continuous X and Y data.}
-#'  \item{combo}{exactly one of ('box', 'box_no_facet', 'dot', 'dot_no_facet', 'facethist', 'facetdensity', 'denstrip', 'blank'). This option is used for either continuous X and categorical Y data or categorical X and continuous Y data.}
-#'  \item{discrete}{exactly one of ('facetbar', 'ratio', 'blank'). This option is used for categorical X and Y data.}
-#'  \item{na}{exactly one of ('na', 'blank').  This option is used when all X data is \code{NA}, all Y data is \code{NA}, or either all X or Y data is \code{NA}.}
+#'  \item{continuous}{This option is used for continuous X and Y data.}
+#'  \item{combo}{This option is used for either continuous X and categorical Y data or categorical X and continuous Y data.}
+#'  \item{discrete}{This option is used for categorical X and Y data.}
+#'  \item{na}{This option is used when all X data is \code{NA}, all Y data is \code{NA}, or either all X or Y data is \code{NA}.}
 #'}
 #'
 #' \code{diag} is a list that may only contain the variables 'continuous', 'discrete', and 'na'. Each element of the diag list is a string implementing the following options:
@@ -611,6 +641,7 @@ ggduo <- function(
 #' @param ... deprecated. Please use \code{mapping}
 #' @param axisLabels either "show" to display axisLabels, "internal" for labels in the diagonal plots, or "none" for no axis labels
 #' @param columnLabels label names to be displayed.  Defaults to names of columns being used.
+#' @param proportions Value to change how much area is given for each plot. Either \code{NULL} (default), numeric value matching respective length, \code{grid::\link[grid]{unit}} object with matching respective length or \code{"auto"} for automatic relative proportions based on the number of levels for categorical variables.
 #' @template ggmatrix-labeller-param
 #' @template ggmatrix-switch-param
 #' @param showStrips boolean to determine if each plot's strips should be displayed. \code{NULL} will default to the top and right side plots only. \code{TRUE} or \code{FALSE} will turn all strips on or off respectively.
@@ -621,11 +652,11 @@ ggduo <- function(
 #' @keywords hplot
 #' @import ggplot2
 #' @references John W Emerson, Walton A Green, Barret Schloerke, Jason Crowley, Dianne Cook, Heike Hofmann, Hadley Wickham. The Generalized Pairs Plot. Journal of Computational and Graphical Statistics, vol. 22, no. 1, pp. 79-91, 2012.
-#' @author Barret Schloerke \email{schloerke@@gmail.com}, Jason Crowley \email{crowley.jason.s@@gmail.com}, Di Cook \email{dicook@@iastate.edu}, Heike Hofmann \email{hofmann@@iastate.edu}, Hadley Wickham \email{h.wickham@@gmail.com}
-#' @return ggmatrix object that if called, will print
+#' @author Barret Schloerke, Jason Crowley, Di Cook, Heike Hofmann, Hadley Wickham
+#' @return \code{\link{ggmatrix}} object that if called, will print
 #' @examples
-#'  # small function to display plots only if it's interactive
-#'  p_ <- GGally::print_if_interactive
+#' # small function to display plots only if it's interactive
+#' p_ <- GGally::print_if_interactive
 #'
 #'
 #' ## Quick example, with and without colour
@@ -724,12 +755,30 @@ ggduo <- function(
 #' # no warning displayed with user supplied function
 #' pm <- ggpairs(tips, 2:3, lower = list(combo = wrap(ggally_facethist, binwidth = 0.5)))
 #' p_(pm)
+#'
+#' ## Remove panel grid lines from correlation plots
+#' pm <- ggpairs(
+#'   flea, columns = 2:4,
+#'   upper = list(continuous = wrap(ggally_cor, displayGrid = FALSE))
+#' )
+#' p_(pm)
+#'
+#' ## Custom with/height of subplots
+#' pm <- ggpairs(tips, columns = c(2, 3, 5))
+#' p_(pm)
+#'
+#' pm <- ggpairs(tips, columns = c(2, 3, 5), proportions = "auto")
+#' p_(pm)
+#'
+#' pm <- ggpairs(tips, columns = c(2, 3, 5), proportions = c(1, 3, 2))
+#' p_(pm)
+#'
 ggpairs <- function(
   data,
   mapping = NULL,
   columns = 1:ncol(data),
   title = NULL,
-  upper = list(continuous = "cor", combo = "box_no_facet", discrete = "facetbar", na = "na"),
+  upper = list(continuous = "cor", combo = "box_no_facet", discrete = "count", na = "na"),
   lower = list(continuous = "points", combo = "facethist", discrete = "facetbar", na = "na"),
   diag = list(continuous = "densityDiag", discrete = "barDiag", na = "naDiag"),
   params = NULL,
@@ -744,6 +793,7 @@ ggpairs <- function(
   legend = NULL,
   cardinality_threshold = 15,
   progress = NULL,
+  proportions = NULL,
   legends = stop("deprecated")
 ){
 
@@ -771,7 +821,7 @@ ggpairs <- function(
 
   upper <- check_and_set_ggpairs_defaults(
     "upper", upper,
-    continuous = "cor", combo = "box_no_facet", discrete = "facetbar", na = "na"
+    continuous = "cor", combo = "box_no_facet", discrete = "count", na = "na"
   )
   lower <- check_and_set_ggpairs_defaults(
     "lower", lower,
@@ -785,6 +835,8 @@ ggpairs <- function(
 
   axisLabels <- fix_axis_label_choice(axisLabels, c("show", "internal", "none"))
 
+  proportions <- ggmatrix_proportions(proportions, data, columns)
+
   # get plot type information
   dataTypes <- plot_types(data, columns, columns, allowDiag = TRUE)
 
@@ -848,7 +900,9 @@ ggpairs <- function(
     data = data_,
     gg = NULL,
     progress = progress,
-    legend = legend
+    legend = legend,
+    xProportions = proportions,
+    yProportions = proportions
   )
 
   plotMatrix
@@ -860,7 +914,7 @@ ggpairs <- function(
 #' Add new aesthetics to a previous aes.
 #'
 #' @keywords internal
-#' @author Barret Schloerke \email{schloerke@@gmail.com}
+#' @author Barret Schloerke
 #' @return aes_ output
 #' @import ggplot2
 #' @rdname add_and_overwrite_aes
@@ -894,12 +948,11 @@ add_and_overwrite_aes <- function(current, new) {
 
 
 
-#' Aesthetic Mapping Color Fill
+#' Aesthetic mapping color fill
 #'
 #' Replace the fill with the color and make color NULL.
 #'
 #' @param current the current aesthetics
-#' @keywords internal
 #' @export
 mapping_color_to_fill <- function(current) {
   if (is.null(current)) {
@@ -1038,6 +1091,53 @@ stop_if_params_exist <- function(params) {
 }
 
 
+ggmatrix_proportions <- function(proportions, data, columns) {
+
+  if (is.null(proportions)) {
+    return(proportions)
+  }
+
+  # relative proportions if "auto"
+  # wrap in isTRUE for safe guarding
+  if (isTRUE(length(proportions) == 1 && proportions == "auto")) {
+    proportions <- c()
+    for (v in columns) {
+      if (is.numeric(data[[v]]))
+        proportions <- c(proportions, NA)
+      else
+        proportions <- c(proportions, length(levels(as.factor(data[[v]]))))
+    }
+    # for numeric variables, the average
+    proportions[is.na(proportions)] <- mean(proportions, na.rm = TRUE)
+    proportions[is.na(proportions)] <- 1 # in case all are numeric
+  } else {
+    is_valid_type <- vapply(proportions, function(x) {
+      (!is.na(x)) &&
+        (
+          grid::is.unit(x) || is.numeric(x)
+        )
+    }, logical(1))
+    if (!all(is_valid_type)) {
+      stop("proportions need to be non-NA numeric values or 'auto'. proportions: ", dput_val(proportions))
+    }
+  }
+
+  if (length(proportions) == 1 && length(columns) > 1) {
+    proportions <- replicate(length(columns), proportions)
+  }
+
+  proportions
+}
+
+dput_val <- function(x) {
+  f <- file()
+  on.exit({
+    close(f)
+  })
+  dput(x, f)
+  ret <- paste0(readLines(f), collapse = "\n")
+  ret
+}
 
 #diamondMatrix <- ggpairs(
 #  diamonds,
