@@ -1,5 +1,7 @@
-
 context("ggpairs")
+# This file takes too long
+testthat::skip_on_cran()
+
 data(tips, package = "reshape")
 
 expect_print <- function(p) {
@@ -467,11 +469,25 @@ test_that("user functions", {
 
   pm1 <- ggpairs(tips, 1:2, lower = list(continuous = "points"))
   p1 <- pm1[2, 1]
-  expect_equivalent(p0, p1)
 
   pm2 <- ggpairs(tips, 1:2, lower = list(continuous = ggally_points))
   p2 <- pm2[2, 1]
-  expect_equivalent(p0, p2)
+
+  expect_equal_plots <- function(x, y) {
+    expect_equal(length(x$layers), 1)
+    expect_equal(length(y$layers), 1)
+    expect_true(
+      "GeomPoint" %in% class(x$layers[[1]]$geom)
+    )
+    expect_true(
+      "GeomPoint" %in% class(y$layers[[1]]$geom)
+    )
+
+    expect_equal(x$labels, list(x = "total_bill", y = "tip"))
+    expect_equal(x$labels, y$labels)
+  }
+  expect_equal_plots(p0, p1)
+  expect_equal_plots(p0, p2)
 })
 
 test_that("NA data", {
@@ -557,6 +573,9 @@ test_that("strip-top and strip-right", {
 
 test_that("subtypes", {
 
+  testthat::skip_on_cran()
+  testthat::skip_if_not_installed("Hmisc")
+
 # list of the different plot types to check
 # continuous
 #    points
@@ -630,18 +649,30 @@ test_that("subtypes", {
       theme(legend.position = "bottom")
   }
 
+
   # re ordered the subs so that density can have no binwidth param
-  conSubs <- list("density", "points", "smooth", "smooth_loess", "cor", "blank")
+  conSubs <- list(
+    "autopoint",
+    "density", "points", "smooth", "smooth_lm", "smooth_loess", "cor",
+    "blank")
   comSubs <- list(
+    "autopoint",
     "box", "dot", "box_no_facet", "dot_no_facet",
     wrap("facethist", binwidth = 1),
-    "facetdensity", wrap("denstrip", binwidth = 1),
+    "facetdensity",
+    "facetdensitystrip",
+    "summarise_by",
+    wrap("denstrip", binwidth = 1),
     "blank"
   )
-  disSubs <- list("ratio", "facetbar", "blank")
+  disSubs <- list(
+    "autopoint", "colbar", "count",
+    "cross", "crosstable", "facetbar",
+    "ratio", "rowbar", "table", "trends",
+    "blank")
 
-  conDiagSubs <- c("densityDiag", wrap("barDiag", binwidth = 1), "blankDiag")
-  disDiagSubs <- c("barDiag", "blankDiag")
+  conDiagSubs <- c("autopointDiag", "densityDiag", wrap("barDiag", binwidth = 1), "blankDiag")
+  disDiagSubs <- c("autopointDiag", "barDiag", "countDiag", "tableDiag", "blankDiag")
 
   # for (fn in list(ggpairs_fn1, ggpairs_fn2, ggduo_fn1, ggduo_fn2)) {
   for (fn_num in 1:4) {
